package org.rcisoft.business.buildtp.service.impl;



import lombok.extern.slf4j.Slf4j;
import org.rcisoft.core.aop.PageUtil;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.core.util.UserUtil;
import org.rcisoft.business.buildtp.dao.BuildTpRepository;
import org.rcisoft.business.buildtp.entity.BuildTp;
import org.rcisoft.business.buildtp.service.BuildTpService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by  on 2018-4-3 10:11:34.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BuildTpServiceImpl implements BuildTpService {

    @Autowired
    private BuildTpRepository buildTpRepository;


    /**
    * 保存 buildTp
    * @param buildTp
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel save(BuildTp buildTp){
        //增加操作
        int line = buildTpRepository.insertSelective(buildTp);
        log.info(UserUtil.getUserInfoProp(buildTp.getToken(),UserUtil.USER_USERNAME)+"新增了ID为"+
            buildTp.getBusinessId()+"的信息");
        return new PersistModel(line);
    }

    /**
    * 逻辑删除
    * @param buildTp
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel remove(BuildTp buildTp){
        int line = buildTpRepository.logicalDelete(buildTp);
        log.info(UserUtil.getUserInfoProp(buildTp.getToken(),UserUtil.USER_USERNAME)+"逻辑删除了ID为"+
        buildTp.getBusinessId()+"的信息");
        return new PersistModel(line);
    }

    /**
    * 修改 buildTp
    * @param buildTp
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel merge(BuildTp buildTp){
        int line = buildTpRepository.updateByPrimaryKeySelective(buildTp);
        log.info(UserUtil.getUserInfoProp(buildTp.getToken(),UserUtil.USER_USERNAME)+"修改了ID为"+
            buildTp.getBusinessId()+"的信息");
        return new PersistModel(line);
    }

    /**
    * 根据id查询 buildTp
    * @param id
    * @return
    */
    @Override
    public BuildTp findById(String id){
        return buildTpRepository.selectByPrimaryKey(id);
    }

    /**
    * 分页查询 buildTp
    * @param buildTp
    * @return
    */
    @Override
    public List<BuildTp> findAllByPagination(PageUtil<BuildTp> paginationUtility,
                                             BuildTp buildTp){
        return buildTpRepository.queryBuildTps(buildTp);
    }

}
